from setuptools import setup, find_packages

setup(name="calendarutil",
      version="2021.3.28",
      url="https://github.com/github-suraj/calendar-util",
      author="Suraj Jaiswal",
      author_email="surajkumarjaiswal053@gmail.com",
      description="Simple and lightweight calendar support for python datetime.date",
      packages=find_packages(),
      long_description=open('README.md').read(),
      long_description_content_type="text/markdown",
      project_urls={"Detail Usage": "https://github.com/github-suraj/calendar-util/blob/main/calendarutil/__init__.py"}
)
